def _jupyter_server_extension_paths():
    return [{
        "module": "jetmlgpt"
    }]

# Jupyter Extension points
def _jupyter_nbextension_paths():
    return [dict(
        section="notebook",
        # the path is relative to the `jetmlgpt` directory
        src="static",
        # directory in the `nbextension/` namespace
        dest="jetmlgpt",
        # _also_ in the `nbextension/` namespace
        require="jetmlgpt/index")]

#def load_jupyter_server_extension(nbapp):
#    nbapp.log.info("my module enabled!")


import os
from notebook.utils import url_path_join
from notebook.base.handlers import IPythonHandler
from tornado import web

class ApiKeyHandler(IPythonHandler):
    @web.authenticated
    def get(self):
        api_key = os.environ.get('OPENAI_API_KEY', 'API key not found')
        self.finish(api_key)

def load_jupyter_server_extension(nb_server_app):
    web_app = nb_server_app.web_app
    host_pattern = '.*$'
    route_pattern = url_path_join(web_app.settings['base_url'], '/get_api_key')
    web_app.add_handlers(host_pattern, [(route_pattern, ApiKeyHandler)])


import setuptools

# Read the contents of your README file
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="jetmlgpt",
    version="0.1.3",
    author="Nick M.",
    author_email="nick@jetml.com",
    description="A Jupyter extension for auto-completing, commenting, and bebugging code in Jupyter notebooks using ChatGPT and GPT4. Set your OpenAI API key in the environment variable OPENAI_API_KEY to activate.",
    long_description=long_description,
    long_description_content_type="text/markdown",    
    url="https://github.com/yourusername/jetmlgpt",
    packages=setuptools.find_packages(),
    include_package_data=True,
    data_files=[
        # like `jupyter nbextension install --sys-prefix`
        ("share/jupyter/nbextensions/jetmlgpt", [
            "jetmlgpt/static/index.js",
        ]),
        # like `jupyter nbextension enable --sys-prefix`
        ("etc/jupyter/nbconfig/notebook.d", [
            "jupyter-config/nbconfig/notebook.d/jetmlgpt.json"
        ]),
        # like `jupyter serverextension enable --sys-prefix`
        ("etc/jupyter/jupyter_notebook_config.d", [
            "jupyter-config/jupyter_notebook_config.d/jetmlgpt.json"
        ])
    ],
    classifiers=[
        'Framework :: Jupyter',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    zip_safe=False
)